"use client"

import { useState, useEffect } from "react"
import { useRouter } from "next/navigation"
import { ArrowLeft } from "lucide-react"
import { Button } from "@/components/ui/button"
import ChatPanel from "@/components/chat-panel"
import WebAppStudio from "@/components/web-app-studio"
import { AIDispatcher } from "@/components/ai-dispatcher"

// Initialize the AI Dispatcher with the API key
const GEMINI_API_KEY = "AIzaSyAWQx3NuGqoVgHrn63CJ7BhWQCHDFQjauM"

export default function StudioPage() {
  const router = useRouter()
  const [viewportHeight, setViewportHeight] = useState(0)
  const [isMobile, setIsMobile] = useState(false)
  const [generatedCode, setGeneratedCode] = useState("")
  const [isGenerating, setIsGenerating] = useState(false)
  const [pendingPrompt, setPendingPrompt] = useState<string | null>(null)
  const [promptJson, setPromptJson] = useState<any>(null)
  const [error, setError] = useState<string | null>(null)
  const [isApiInitialized, setIsApiInitialized] = useState(false)

  // Initialize the API client
  useEffect(() => {
    if (!isApiInitialized) {
      try {
        AIDispatcher.initialize(GEMINI_API_KEY)
        setIsApiInitialized(true)
      } catch (error) {
        console.error("Failed to initialize API client:", error)
        setError("Nie udało się zainicjalizować klienta API")
      }
    }
  }, [isApiInitialized])

  // Check if device is mobile and get viewport height
  useEffect(() => {
    const checkMobileAndViewport = () => {
      const isMobileDevice = window.innerWidth < 768
      setIsMobile(isMobileDevice)
      setViewportHeight(window.innerHeight)
    }

    checkMobileAndViewport()
    window.addEventListener("resize", checkMobileAndViewport)

    return () => {
      window.removeEventListener("resize", checkMobileAndViewport)
    }
  }, [])

  const handleBackToChat = () => {
    router.push("/")
  }

  const handleChatMessage = async (message: string) => {
    if (!isApiInitialized) {
      setError("API nie zostało zainicjalizowane. Odśwież stronę i spróbuj ponownie.")
      return
    }

    setError(null)

    // Process the chat message and potentially generate a prompt for the AI Programmer
    if (
      message.toLowerCase().includes("stwórz") ||
      message.toLowerCase().includes("zbuduj") ||
      message.toLowerCase().includes("generuj") ||
      message.toLowerCase().includes("zrób") ||
      message.toLowerCase().includes("create") ||
      message.toLowerCase().includes("build") ||
      message.toLowerCase().includes("generate") ||
      message.toLowerCase().includes("make")
    ) {
      try {
        // Generate a technical prompt based on the user's message
        const technicalPrompt = await AIDispatcher.generateTechnicalPrompt(message)

        // Set the pending prompt for user approval
        setPendingPrompt(technicalPrompt)

        try {
          // Parse the JSON for later use
          const jsonPrompt = JSON.parse(technicalPrompt)
          setPromptJson(jsonPrompt)
        } catch (e) {
          console.error("Error parsing JSON prompt:", e)
          setError("Błąd parsowania promptu JSON. Spróbuj ponownie z innym zapytaniem.")
        }
      } catch (error) {
        console.error("Error generating technical prompt:", error)
        setError("Nie udało się wygenerować technicznego promptu. Spróbuj ponownie za chwilę.")
      }
    }
  }

  const handleApprovePrompt = () => {
    if (!pendingPrompt) return

    // Set generating state
    setIsGenerating(true)
    setError(null)

    // Send the prompt to the AI Programmer
    AIDispatcher.sendPromptToProgrammer(pendingPrompt)
      .then((response) => {
        if (response.status === "error") {
          setError("Wystąpił błąd podczas generowania kodu")
        } else {
          // Update the generated code
          setGeneratedCode(response.output)
        }
        // Reset generating state
        setIsGenerating(false)
        // Clear the pending prompt
        setPendingPrompt(null)
      })
      .catch((error) => {
        console.error("Error generating code:", error)
        setError("Wystąpił błąd podczas generowania kodu. Spróbuj ponownie za chwilę.")
        setIsGenerating(false)
        setPendingPrompt(null)
      })
  }

  const handleRejectPrompt = () => {
    // Clear the pending prompt
    setPendingPrompt(null)
    setPromptJson(null)
    setError(null)
  }

  return (
    <div
      className="flex flex-col md:flex-row h-screen bg-gray-50 overflow-hidden"
      style={{ height: isMobile ? `${viewportHeight}px` : "100vh" }}
    >
      {/* Mobile header */}
      <div className="md:hidden fixed top-0 left-0 right-0 h-12 flex items-center px-4 z-20 bg-white border-b">
        <Button variant="ghost" size="icon" className="h-8 w-8" onClick={handleBackToChat}>
          <ArrowLeft className="h-5 w-5" />
        </Button>
        <h1 className="text-base font-medium ml-2">Web App Studio</h1>
      </div>

      {/* Left panel - Chat */}
      <div className="w-full md:w-1/3 lg:w-2/5 h-full overflow-hidden md:border-r">
        {/* Desktop header */}
        <div className="hidden md:flex h-12 items-center px-4 border-b bg-white">
          <Button variant="ghost" size="icon" className="h-8 w-8" onClick={handleBackToChat}>
            <ArrowLeft className="h-5 w-5" />
          </Button>
          <h1 className="text-base font-medium ml-2">AI Asystent</h1>
        </div>

        {/* Chat panel */}
        <div className={`h-full ${isMobile ? "pt-12" : ""}`}>
          <ChatPanel
            className="h-full"
            onSendMessage={handleChatMessage}
            pendingPrompt={pendingPrompt}
            onApprovePrompt={handleApprovePrompt}
            onRejectPrompt={handleRejectPrompt}
            isGenerating={isGenerating}
            promptJson={promptJson}
            error={error}
            apiInitialized={isApiInitialized}
          />
        </div>
      </div>

      {/* Right panel - Web App Studio */}
      <div className="hidden md:block md:w-2/3 lg:w-3/5 h-full overflow-hidden">
        <WebAppStudio
          className="h-full"
          generatedCode={generatedCode}
          isGenerating={isGenerating}
          promptJson={promptJson}
          error={error}
        />
      </div>
    </div>
  )
}
