"use client"

import type React from "react"

import { useState, useRef, useEffect } from "react"
import {
  Search,
  Plus,
  Lightbulb,
  ArrowUp,
  RefreshCcw,
  Copy,
  Share2,
  ThumbsUp,
  ThumbsDown,
  Code,
  CheckCircle,
  XCircle,
  Loader2,
  AlertCircle,
  Wifi,
  WifiOff,
} from "lucide-react"
import { Button } from "@/components/ui/button"
import { Textarea } from "@/components/ui/textarea"
import { cn } from "@/lib/utils"
import { Badge } from "@/components/ui/badge"
import { AIDispatcher } from "@/components/ai-dispatcher"

type ActiveButton = "none" | "add" | "deepSearch" | "think"
type MessageType = "user" | "system" | "prompt" | "error" | "status"

interface Message {
  id: string
  content: string
  type: MessageType
  completed?: boolean
  newSection?: boolean
}

interface MessageSection {
  id: string
  messages: Message[]
  isNewSection: boolean
  isActive?: boolean
  sectionIndex: number
}

interface StreamingWord {
  id: number
  text: string
}

interface ChatPanelProps {
  className?: string
  onSendMessage?: (message: string) => void
  pendingPrompt?: string | null
  onApprovePrompt?: () => void
  onRejectPrompt?: () => void
  isGenerating?: boolean
  promptJson?: any
  error?: string | null
  apiInitialized?: boolean
}

// Faster word delay for smoother streaming
const WORD_DELAY = 40 // ms per word
const CHUNK_SIZE = 2 // Number of words to add at once

export default function ChatPanel({
  className,
  onSendMessage,
  pendingPrompt,
  onApprovePrompt,
  onRejectPrompt,
  isGenerating = false,
  promptJson,
  error = null,
  apiInitialized = false,
}: ChatPanelProps) {
  const [inputValue, setInputValue] = useState("")
  const textareaRef = useRef<HTMLTextAreaElement>(null)
  const chatContainerRef = useRef<HTMLDivElement>(null)
  const newSectionRef = useRef<HTMLDivElement>(null)
  const [hasTyped, setHasTyped] = useState(false)
  const [activeButton, setActiveButton] = useState<ActiveButton>("none")
  const [isMobile, setIsMobile] = useState(false)
  const [messages, setMessages] = useState<Message[]>([])
  const [messageSections, setMessageSections] = useState<MessageSection[]>([])
  const [isStreaming, setIsStreaming] = useState(false)
  const [streamingWords, setStreamingWords] = useState<StreamingWord[]>([])
  const [streamingMessageId, setStreamingMessageId] = useState<string | null>(null)
  const messagesEndRef = useRef<HTMLDivElement>(null)
  const [completedMessages, setCompletedMessages] = useState<Set<string>>(new Set())
  const [activeSectionId, setActiveSectionId] = useState<string | null>(null)
  const inputContainerRef = useRef<HTMLDivElement>(null)
  const shouldFocusAfterStreamingRef = useRef(false)
  // Store selection state
  const selectionStateRef = useRef<{ start: number | null; end: number | null }>({ start: null, end: null })

  // Check if device is mobile
  useEffect(() => {
    const checkMobile = () => {
      const isMobileDevice = window.innerWidth < 768
      setIsMobile(isMobileDevice)
    }

    checkMobile()
    window.addEventListener("resize", checkMobile)

    return () => {
      window.removeEventListener("resize", checkMobile)
    }
  }, [])

  // Add API status message when apiInitialized changes
  useEffect(() => {
    const statusMessageId = `api-status-${Date.now()}`
    setMessages((prev) => [
      ...prev,
      {
        id: statusMessageId,
        content: apiInitialized ? "Połączono z API Gemini. Możesz teraz zadawać pytania." : "Łączenie z API Gemini...",
        type: "status",
        completed: true,
        newSection: prev.length === 0,
      },
    ])
  }, [apiInitialized])

  // Add pending prompt to messages when it changes
  useEffect(() => {
    if (pendingPrompt && !isGenerating) {
      const promptMessageId = `prompt-${Date.now()}`
      setMessages((prev) => [
        ...prev,
        {
          id: promptMessageId,
          content: pendingPrompt,
          type: "prompt",
          completed: true,
          newSection: false,
        },
      ])
    }
  }, [pendingPrompt, isGenerating])

  // Add generating message when isGenerating changes to true
  useEffect(() => {
    if (isGenerating) {
      const generatingMessageId = `generating-${Date.now()}`
      setMessages((prev) => [
        ...prev,
        {
          id: generatingMessageId,
          content: "Generuję kod na podstawie Twojego zapytania...",
          type: "system",
          completed: true,
          newSection: false,
        },
      ])
    }
  }, [isGenerating])

  // Add error message when error changes
  useEffect(() => {
    if (error) {
      const errorMessageId = `error-${Date.now()}`
      setMessages((prev) => [
        ...prev,
        {
          id: errorMessageId,
          content: error,
          type: "error",
          completed: true,
          newSection: false,
        },
      ])
    }
  }, [error])

  // Organize messages into sections
  useEffect(() => {
    if (messages.length === 0) {
      setMessageSections([])
      setActiveSectionId(null)
      return
    }

    const sections: MessageSection[] = []
    let currentSection: MessageSection = {
      id: `section-${Date.now()}-0`,
      messages: [],
      isNewSection: false,
      sectionIndex: 0,
    }

    messages.forEach((message) => {
      if (message.newSection) {
        // Start a new section
        if (currentSection.messages.length > 0) {
          // Mark previous section as inactive
          sections.push({
            ...currentSection,
            isActive: false,
          })
        }

        // Create new active section
        const newSectionId = `section-${Date.now()}-${sections.length}`
        currentSection = {
          id: newSectionId,
          messages: [message],
          isNewSection: true,
          isActive: true,
          sectionIndex: sections.length,
        }

        // Update active section ID
        setActiveSectionId(newSectionId)
      } else {
        // Add to current section
        currentSection.messages.push(message)
      }
    })

    // Add the last section if it has messages
    if (currentSection.messages.length > 0) {
      sections.push(currentSection)
    }

    setMessageSections(sections)
  }, [messages])

  // Scroll to maximum position when new section is created, but only for sections after the first
  useEffect(() => {
    if (messageSections.length > 1) {
      setTimeout(() => {
        const scrollContainer = chatContainerRef.current

        if (scrollContainer) {
          // Scroll to maximum possible position
          scrollContainer.scrollTo({
            top: scrollContainer.scrollHeight,
            behavior: "smooth",
          })
        }
      }, 100)
    }
  }, [messageSections])

  // Focus the textarea on component mount (only on desktop)
  useEffect(() => {
    if (textareaRef.current && !isMobile) {
      textareaRef.current.focus()
    }
  }, [isMobile])

  // Set focus back to textarea after streaming ends (only on desktop)
  useEffect(() => {
    if (!isStreaming && shouldFocusAfterStreamingRef.current && !isMobile) {
      focusTextarea()
      shouldFocusAfterStreamingRef.current = false
    }
  }, [isStreaming, isMobile])

  // Save the current selection state
  const saveSelectionState = () => {
    if (textareaRef.current) {
      selectionStateRef.current = {
        start: textareaRef.current.selectionStart,
        end: textareaRef.current.selectionEnd,
      }
    }
  }

  // Restore the saved selection state
  const restoreSelectionState = () => {
    const textarea = textareaRef.current
    const { start, end } = selectionStateRef.current

    if (textarea && start !== null && end !== null) {
      // Focus first, then set selection range
      textarea.focus()
      textarea.setSelectionRange(start, end)
    } else if (textarea) {
      // If no selection was saved, just focus
      textarea.focus()
    }
  }

  const focusTextarea = () => {
    if (textareaRef.current && !isMobile) {
      textareaRef.current.focus()
    }
  }

  const handleInputContainerClick = (e: React.MouseEvent<HTMLDivElement>) => {
    // Only focus if clicking directly on the container, not on buttons or other interactive elements
    if (
      e.target === e.currentTarget ||
      (e.currentTarget === inputContainerRef.current && !(e.target as HTMLElement).closest("button"))
    ) {
      if (textareaRef.current) {
        textareaRef.current.focus()
      }
    }
  }

  const simulateTextStreaming = async (text: string) => {
    // Split text into words
    const words = text.split(" ")
    let currentIndex = 0
    setStreamingWords([])
    setIsStreaming(true)

    return new Promise<void>((resolve) => {
      const streamInterval = setInterval(() => {
        if (currentIndex < words.length) {
          // Add a few words at a time
          const nextIndex = Math.min(currentIndex + CHUNK_SIZE, words.length)
          const newWords = words.slice(currentIndex, nextIndex)

          setStreamingWords((prev) => [
            ...prev,
            {
              id: Date.now() + currentIndex,
              text: newWords.join(" ") + " ",
            },
          ])

          currentIndex = nextIndex
        } else {
          clearInterval(streamInterval)
          resolve()
        }
      }, WORD_DELAY)
    })
  }

  const simulateAIResponse = async (userMessage: string) => {
    try {
      // Get response from AI Dispatcher
      const response = await AIDispatcher.generateAssistantResponse(userMessage)

      // Create a new message with empty content
      const messageId = Date.now().toString()
      setStreamingMessageId(messageId)

      setMessages((prev) => [
        ...prev,
        {
          id: messageId,
          content: "",
          type: "system",
        },
      ])

      // Add a delay before the second vibration
      setTimeout(() => {
        // Add vibration when streaming begins
        navigator.vibrate(50)
      }, 200) // 200ms delay to make it distinct from the first vibration

      // Stream the text
      await simulateTextStreaming(response)

      // Update with complete message
      setMessages((prev) =>
        prev.map((msg) => (msg.id === messageId ? { ...msg, content: response, completed: true } : msg)),
      )

      // Add to completed messages set to prevent re-animation
      setCompletedMessages((prev) => new Set(prev).add(messageId))

      // Add vibration when streaming ends
      navigator.vibrate(50)

      // Reset streaming state
      setStreamingWords([])
      setStreamingMessageId(null)
      setIsStreaming(false)
    } catch (error) {
      console.error("Error generating AI response:", error)
      setIsStreaming(false)

      // Add error message
      setMessages((prev) => [
        ...prev,
        {
          id: `error-${Date.now()}`,
          content: "Przepraszam, wystąpił błąd podczas generowania odpowiedzi. Spróbuj ponownie za chwilę.",
          type: "error",
          completed: true,
        },
      ])
    }
  }

  const handleInputChange = (e: React.ChangeEvent<HTMLTextAreaElement>) => {
    const newValue = e.target.value

    // Only allow input changes when not streaming
    if (!isStreaming) {
      setInputValue(newValue)

      if (newValue.trim() !== "" && !hasTyped) {
        setHasTyped(true)
      } else if (newValue.trim() === "" && hasTyped) {
        setHasTyped(false)
      }

      const textarea = textareaRef.current
      if (textarea) {
        textarea.style.height = "auto"
        const newHeight = Math.max(24, Math.min(textarea.scrollHeight, 160))
        textarea.style.height = `${newHeight}px`
      }
    }
  }

  const handleSubmit = (e: React.FormEvent) => {
    e.preventDefault()
    if (inputValue.trim() && !isStreaming && !isGenerating && apiInitialized) {
      // Add vibration when message is submitted
      navigator.vibrate(50)

      const userMessage = inputValue.trim()

      // Add as a new section if messages already exist
      const shouldAddNewSection = messages.length > 0

      const newUserMessage = {
        id: `user-${Date.now()}`,
        content: userMessage,
        type: "user" as MessageType,
        newSection: shouldAddNewSection,
      }

      // Reset input before starting the AI response
      setInputValue("")
      setHasTyped(false)
      setActiveButton("none")

      if (textareaRef.current) {
        textareaRef.current.style.height = "auto"
      }

      // Add the message after resetting input
      setMessages((prev) => [...prev, newUserMessage])

      // Only focus the textarea on desktop, not on mobile
      if (!isMobile) {
        focusTextarea()
      } else {
        // On mobile, blur the textarea to dismiss the keyboard
        if (textareaRef.current) {
          textareaRef.current.blur()
        }
      }

      // If there's an external handler, call it
      if (onSendMessage) {
        onSendMessage(userMessage)
      }

      // Start AI response
      simulateAIResponse(userMessage)
    }
  }

  const handleKeyDown = (e: React.KeyboardEvent<HTMLTextAreaElement>) => {
    // Handle Cmd+Enter on both mobile and desktop
    if (!isStreaming && e.key === "Enter" && e.metaKey) {
      e.preventDefault()
      handleSubmit(e)
      return
    }

    // Only handle regular Enter key (without Shift) on desktop
    if (!isStreaming && !isMobile && e.key === "Enter" && !e.shiftKey) {
      e.preventDefault()
      handleSubmit(e)
    }
  }

  const toggleButton = (button: ActiveButton) => {
    if (!isStreaming) {
      // Save the current selection state before toggling
      saveSelectionState()

      setActiveButton((prev) => (prev === button ? "none" : button))

      // Restore the selection state after toggling
      setTimeout(() => {
        restoreSelectionState()
      }, 0)
    }
  }

  const renderMessage = (message: Message) => {
    const isCompleted = completedMessages.has(message.id)

    if (message.type === "prompt") {
      return (
        <div key={message.id} className="flex flex-col items-start w-full">
          <div className="bg-amber-50 border border-amber-200 rounded-md p-4 w-full">
            <div className="flex items-center mb-2">
              <Code className="h-4 w-4 mr-2 text-amber-600" />
              <span className="text-sm font-medium text-amber-800">Techniczny Prompt</span>
              <Badge variant="outline" className="ml-2 bg-amber-100 text-amber-800 border-amber-300">
                Oczekuje na zatwierdzenie
              </Badge>
            </div>
            <pre className="text-xs bg-amber-100 p-2 rounded overflow-auto max-h-40 whitespace-pre-wrap">
              {message.content}
            </pre>
            <div className="flex justify-end mt-3 gap-2">
              <Button
                size="sm"
                variant="outline"
                className="text-red-600 border-red-200 hover:bg-red-50"
                onClick={onRejectPrompt}
              >
                <XCircle className="h-4 w-4 mr-1" />
                Odrzuć
              </Button>
              <Button size="sm" className="bg-green-600 hover:bg-green-700 text-white" onClick={onApprovePrompt}>
                <CheckCircle className="h-4 w-4 mr-1" />
                Zatwierdź i generuj
              </Button>
            </div>
          </div>
        </div>
      )
    }

    if (message.type === "error") {
      return (
        <div key={message.id} className="flex flex-col items-start w-full">
          <div className="bg-red-50 border border-red-200 rounded-md p-3 w-full">
            <div className="flex items-center">
              <AlertCircle className="h-4 w-4 mr-2 text-red-600" />
              <span className="text-sm text-red-800">{message.content}</span>
            </div>
          </div>
        </div>
      )
    }

    if (message.type === "status") {
      return (
        <div key={message.id} className="flex flex-col items-center w-full my-2">
          <div className="bg-blue-50 border border-blue-200 rounded-md px-3 py-2">
            <div className="flex items-center">
              {apiInitialized ? (
                <Wifi className="h-4 w-4 mr-2 text-blue-600" />
              ) : (
                <WifiOff className="h-4 w-4 mr-2 text-gray-500" />
              )}
              <span className="text-sm text-blue-800">{message.content}</span>
            </div>
          </div>
        </div>
      )
    }

    return (
      <div key={message.id} className={cn("flex flex-col", message.type === "user" ? "items-end" : "items-start")}>
        <div
          className={cn(
            "max-w-[80%] px-4 py-2 rounded-2xl",
            message.type === "user" ? "bg-white border border-gray-200 rounded-br-none" : "text-gray-900",
          )}
        >
          {/* For user messages or completed system messages, render without animation */}
          {message.content && (
            <span className={message.type === "system" && !isCompleted ? "animate-fade-in" : ""}>
              {message.content}
            </span>
          )}

          {/* For streaming messages, render with animation */}
          {message.id === streamingMessageId && (
            <span className="inline">
              {streamingWords.map((word) => (
                <span key={word.id} className="animate-fade-in inline">
                  {word.text}
                </span>
              ))}
            </span>
          )}
        </div>

        {/* Message actions */}
        {message.type === "system" && message.completed && (
          <div className="flex items-center gap-2 px-4 mt-1 mb-2">
            <button className="text-gray-400 hover:text-gray-600 transition-colors">
              <RefreshCcw className="h-4 w-4" />
            </button>
            <button className="text-gray-400 hover:text-gray-600 transition-colors">
              <Copy className="h-4 w-4" />
            </button>
            <button className="text-gray-400 hover:text-gray-600 transition-colors">
              <Share2 className="h-4 w-4" />
            </button>
            <button className="text-gray-400 hover:text-gray-600 transition-colors">
              <ThumbsUp className="h-4 w-4" />
            </button>
            <button className="text-gray-400 hover:text-gray-600 transition-colors">
              <ThumbsDown className="h-4 w-4" />
            </button>
          </div>
        )}
      </div>
    )
  }

  return (
    <div className={cn("flex flex-col h-full bg-gray-50", className)}>
      <div ref={chatContainerRef} className="flex-grow pb-32 pt-4 px-4 overflow-y-auto">
        <div className="max-w-full mx-auto space-y-4">
          {messageSections.map((section) => (
            <div key={section.id}>
              {section.isNewSection && (
                <div className="pt-4 flex flex-col justify-start">
                  {section.messages.map((message) => renderMessage(message))}
                </div>
              )}

              {!section.isNewSection && <div>{section.messages.map((message) => renderMessage(message))}</div>}
            </div>
          ))}
          <div ref={messagesEndRef} />
        </div>
      </div>

      <div className="fixed bottom-0 left-0 right-0 p-4 bg-gray-50 w-full md:w-1/3 lg:w-2/5">
        <form onSubmit={handleSubmit} className="max-w-full mx-auto">
          <div
            ref={inputContainerRef}
            className={cn(
              "relative w-full rounded-3xl border border-gray-200 bg-white p-3 cursor-text",
              (isStreaming || isGenerating) && "opacity-80",
              !apiInitialized && "opacity-50",
            )}
            onClick={handleInputContainerClick}
          >
            <div className="pb-9">
              <Textarea
                ref={textareaRef}
                placeholder={
                  !apiInitialized
                    ? "Łączenie z API Gemini..."
                    : isStreaming
                      ? "Czekam na odpowiedź..."
                      : isGenerating
                        ? "Generuję kod..."
                        : "Zapytaj o cokolwiek"
                }
                className="min-h-[24px] max-h-[160px] w-full rounded-3xl border-0 bg-transparent text-gray-900 placeholder:text-gray-400 placeholder:text-base focus-visible:ring-0 focus-visible:ring-offset-0 text-base pl-2 pr-4 pt-0 pb-0 resize-none overflow-y-auto leading-tight"
                value={inputValue}
                onChange={handleInputChange}
                onKeyDown={handleKeyDown}
                disabled={isGenerating || !apiInitialized}
              />
            </div>

            <div className="absolute bottom-3 left-3 right-3">
              <div className="flex items-center justify-between">
                <div className="flex items-center space-x-2">
                  <Button
                    type="button"
                    variant="outline"
                    size="icon"
                    className={cn(
                      "rounded-full h-8 w-8 flex-shrink-0 border-gray-200 p-0 transition-colors",
                      activeButton === "add" && "bg-gray-100 border-gray-300",
                    )}
                    onClick={() => toggleButton("add")}
                    disabled={isStreaming || isGenerating || !apiInitialized}
                  >
                    <Plus className={cn("h-4 w-4 text-gray-500", activeButton === "add" && "text-gray-700")} />
                    <span className="sr-only">Dodaj</span>
                  </Button>

                  <Button
                    type="button"
                    variant="outline"
                    className={cn(
                      "rounded-full h-8 px-3 flex items-center border-gray-200 gap-1.5 transition-colors",
                      activeButton === "deepSearch" && "bg-gray-100 border-gray-300",
                    )}
                    onClick={() => toggleButton("deepSearch")}
                    disabled={isStreaming || isGenerating || !apiInitialized}
                  >
                    <Search className={cn("h-4 w-4 text-gray-500", activeButton === "deepSearch" && "text-gray-700")} />
                    <span className={cn("text-gray-900 text-sm", activeButton === "deepSearch" && "font-medium")}>
                      DeepSearch
                    </span>
                  </Button>

                  <Button
                    type="button"
                    variant="outline"
                    className={cn(
                      "rounded-full h-8 px-3 flex items-center border-gray-200 gap-1.5 transition-colors",
                      activeButton === "think" && "bg-gray-100 border-gray-300",
                    )}
                    onClick={() => toggleButton("think")}
                    disabled={isStreaming || isGenerating || !apiInitialized}
                  >
                    <Lightbulb className={cn("h-4 w-4 text-gray-500", activeButton === "think" && "text-gray-700")} />
                    <span className={cn("text-gray-900 text-sm", activeButton === "think" && "font-medium")}>
                      Pomyśl
                    </span>
                  </Button>
                </div>

                <Button
                  type="submit"
                  variant="outline"
                  size="icon"
                  className={cn(
                    "rounded-full h-8 w-8 border-0 flex-shrink-0 transition-all duration-200",
                    hasTyped ? "bg-black scale-110" : "bg-gray-200",
                    isGenerating && "bg-amber-500",
                    !apiInitialized && "bg-gray-300",
                  )}
                  disabled={!inputValue.trim() || isStreaming || isGenerating || !apiInitialized}
                >
                  {isGenerating || !apiInitialized ? (
                    <Loader2 className="h-4 w-4 text-white animate-spin" />
                  ) : (
                    <ArrowUp className={cn("h-4 w-4 transition-colors", hasTyped ? "text-white" : "text-gray-500")} />
                  )}
                  <span className="sr-only">
                    {!apiInitialized ? "Łączenie" : isGenerating ? "Generowanie" : "Wyślij"}
                  </span>
                </Button>
              </div>
            </div>
          </div>
        </form>
      </div>
    </div>
  )
}
