"use client"

import { useState, useEffect, useRef } from "react"
import { Tabs, TabsList, TabsTrigger, TabsContent } from "@/components/ui/tabs"
import { Badge } from "@/components/ui/badge"
import { Code, Eye, Terminal, Loader2, AlertCircle, RefreshCw, Copy, Download } from "lucide-react"
import { Button } from "@/components/ui/button"

interface WebAppStudioProps {
  className?: string
  generatedCode?: string
  isGenerating?: boolean
  promptJson?: any
  error?: string | null
}

export default function WebAppStudio({
  className,
  generatedCode = "",
  isGenerating = false,
  promptJson,
  error = null,
}: WebAppStudioProps) {
  const [activeTab, setActiveTab] = useState("preview")
  const [previewReady, setPreviewReady] = useState(false)
  const [previewError, setPreviewError] = useState<string | null>(null)
  const [code, setCode] = useState(`
// Domyślny kod przykładowy
import { useState } from 'react'

export default function Home() {
  const [count, setCount] = useState(0)
  
  return (
    <div className="flex min-h-screen flex-col items-center justify-center p-24">
      <h1 className="text-4xl font-bold mb-8">Podgląd aplikacji</h1>
      <p className="mb-4">To jest podgląd na żywo Twojej aplikacji</p>
      
      <div className="p-4 border rounded-md">
        <p className="text-xl mb-2">Licznik: {count}</p>
        <button 
          onClick={() => setCount(count + 1)}
          className="px-4 py-2 bg-blue-500 text-white rounded-md hover:bg-blue-600"
        >
          Zwiększ
        </button>
      </div>
    </div>
  )
}
`)
  const iframeRef = useRef<HTMLIFrameElement>(null)
  const [isRefreshing, setIsRefreshing] = useState(false)

  // Update code when new code is generated
  useEffect(() => {
    if (generatedCode) {
      setCode(generatedCode)
      setPreviewReady(false)
      setPreviewError(null)

      // Small delay to ensure the state updates before rendering
      setTimeout(() => {
        updatePreview(generatedCode)
      }, 100)
    }
  }, [generatedCode])

  // Set preview as ready after a delay if there's no generated code
  useEffect(() => {
    if (!generatedCode && !previewReady) {
      const timer = setTimeout(() => {
        setPreviewReady(true)
        updatePreview(code)
      }, 1000)

      return () => clearTimeout(timer)
    }
  }, [generatedCode, previewReady, code])

  // Auto-switch to preview tab when code is generated
  useEffect(() => {
    if (generatedCode && !isGenerating) {
      setActiveTab("preview")
    }
  }, [generatedCode, isGenerating])

  // Extract component name from code
  const extractComponentName = (codeToAnalyze: string): string => {
    // Look for export default function ComponentName or export default class ComponentName
    const exportDefaultMatch = codeToAnalyze.match(/export\s+default\s+(function|class)\s+(\w+)/i)
    if (exportDefaultMatch && exportDefaultMatch[2]) {
      return exportDefaultMatch[2]
    }

    // Look for const/let/var ComponentName = () => or const/let/var ComponentName = function()
    const constFunctionMatch = codeToAnalyze.match(/(?:const|let|var)\s+(\w+)\s*=\s*(?:\(|function)/i)
    if (constFunctionMatch && constFunctionMatch[1]) {
      return constFunctionMatch[1]
    }

    // If we have promptJson, use that
    if (promptJson && promptJson.component) {
      return promptJson.component
    }

    // Default fallback names
    return "Home"
  }

  // Clean up code for preview
  const prepareCodeForPreview = (codeToClean: string): string => {
    // Remove imports that won't work in the preview
    let cleanedCode = codeToClean
      .replace(/import\s+.*?from\s+['"]next\/navigation['"];?/g, "// Next imports removed for preview")
      .replace(/import\s+.*?from\s+['"]next\/router['"];?/g, "// Next imports removed for preview")
      .replace(/import\s+.*?from\s+['"]@\/components\/ui\/.*?['"];?/g, "// UI component imports removed for preview")

    // Add mock for useRouter
    if (cleanedCode.includes("useRouter")) {
      cleanedCode = `
// Mock for useRouter
const useRouter = () => ({
  push: (path) => console.log('Navigation to:', path),
  back: () => console.log('Navigation: back'),
  pathname: '/current-path'
});

${cleanedCode}`
    }

    return cleanedCode
  }

  // Update the preview iframe with the generated code
  const updatePreview = (codeToRender: string) => {
    setPreviewReady(false)
    setPreviewError(null)
    setIsRefreshing(true)

    if (iframeRef.current) {
      const iframe = iframeRef.current
      const iframeDocument = iframe.contentDocument || iframe.contentWindow?.document

      if (iframeDocument) {
        try {
          const componentName = extractComponentName(codeToRender)
          const preparedCode = prepareCodeForPreview(codeToRender)

          // Create a basic HTML structure with React and Tailwind CSS
          const htmlContent = `
            <!DOCTYPE html>
            <html lang="pl">
            <head>
              <meta charset="UTF-8">
              <meta name="viewport" content="width=device-width, initial-scale=1.0">
              <title>Live Preview</title>
              <script src="https://unpkg.com/react@18/umd/react.development.js"></script>
              <script src="https://unpkg.com/react-dom@18/umd/react-dom.development.js"></script>
              <script src="https://unpkg.com/@babel/standalone/babel.min.js"></script>
              <script src="https://cdn.tailwindcss.com"></script>
              <style>
                body { margin: 0; padding: 0; }
                #root { min-height: 100vh; }
                .preview-error { 
                  padding: 1rem; 
                  color: #ef4444; 
                  background-color: #fef2f2; 
                  border: 1px solid #fee2e2;
                  border-radius: 0.375rem;
                  margin: 1rem;
                }
                .preview-error pre {
                  white-space: pre-wrap;
                  overflow-wrap: break-word;
                  background-color: #fff;
                  padding: 0.5rem;
                  border-radius: 0.25rem;
                  margin-top: 0.5rem;
                  font-size: 0.875rem;
                  font-family: monospace;
                }
              </style>
            </head>
            <body>
              <div id="root"></div>
              <script type="text/babel">
                try {
                  ${preparedCode}
                  
                  // Render the component
                  const rootElement = document.getElementById('root');
                  const root = ReactDOM.createRoot(rootElement);
                  
                  try {
                    // Try to find the default export or named component
                    const Component = typeof ${componentName} !== 'undefined' ? ${componentName} : 
                                      typeof Home !== 'undefined' ? Home : 
                                      typeof LoginForm !== 'undefined' ? LoginForm : 
                                      typeof RegisterForm !== 'undefined' ? RegisterForm : 
                                      typeof Dashboard !== 'undefined' ? Dashboard : 
                                      typeof MainComponent !== 'undefined' ? MainComponent : 
                                      typeof CustomComponent !== 'undefined' ? CustomComponent :
                                      typeof CustomForm !== 'undefined' ? CustomForm :
                                      () => <div>No component found</div>;
                    
                    root.render(<Component />);
                    
                    // Signal to parent that rendering is complete
                    window.parent.postMessage({ type: 'PREVIEW_READY', success: true }, '*');
                  } catch (renderError) {
                    console.error('Error rendering component:', renderError);
                    root.render(
                      <div className="preview-error">
                        <h2>Error rendering component:</h2>
                        <pre>{renderError.toString()}</pre>
                      </div>
                    );
                    // Signal to parent that rendering failed
                    window.parent.postMessage({ 
                      type: 'PREVIEW_ERROR', 
                      error: renderError.toString() 
                    }, '*');
                  }
                } catch (parseError) {
                  console.error('Error parsing code:', parseError);
                  document.getElementById('root').innerHTML = \`
                    <div class="preview-error">
                      <h2>Error parsing code:</h2>
                      <pre>\${parseError.toString()}</pre>
                    </div>
                  \`;
                  // Signal to parent that parsing failed
                  window.parent.postMessage({ 
                    type: 'PREVIEW_ERROR', 
                    error: parseError.toString() 
                  }, '*');
                }
              </script>
            </body>
            </html>
          `

          iframeDocument.open()
          iframeDocument.write(htmlContent)
          iframeDocument.close()

          // Listen for messages from the iframe
          const messageHandler = (event: MessageEvent) => {
            if (event.data.type === "PREVIEW_READY") {
              setPreviewReady(true)
              setIsRefreshing(false)
            } else if (event.data.type === "PREVIEW_ERROR") {
              setPreviewError(event.data.error)
              setPreviewReady(true)
              setIsRefreshing(false)
            }
          }

          window.addEventListener("message", messageHandler)

          // Set a timeout in case the iframe doesn't respond
          const timeout = setTimeout(() => {
            setPreviewReady(true)
            setIsRefreshing(false)
            if (!previewError) {
              setPreviewError("Timeout waiting for preview to load")
            }
          }, 5000)

          return () => {
            window.removeEventListener("message", messageHandler)
            clearTimeout(timeout)
          }
        } catch (error) {
          console.error("Error setting up preview:", error)
          setPreviewError(error instanceof Error ? error.message : "Unknown error")
          setPreviewReady(true)
          setIsRefreshing(false)
        }
      }
    }
  }

  // Handle manual refresh of the preview
  const handleRefreshPreview = () => {
    updatePreview(code)
  }

  // Copy code to clipboard
  const handleCopyCode = () => {
    navigator.clipboard
      .writeText(code)
      .then(() => {
        // Could add a toast notification here
        console.log("Code copied to clipboard")
      })
      .catch((err) => {
        console.error("Failed to copy code:", err)
      })
  }

  // Get component name from promptJson or code
  const getComponentName = () => {
    if (promptJson && promptJson.component) {
      return promptJson.component
    }

    return extractComponentName(code)
  }

  return (
    <div className={`flex flex-col h-full overflow-hidden ${className}`}>
      {/* Header */}
      <div className="border-b p-4 flex items-center justify-between bg-white">
        <div className="flex items-center gap-3">
          <h2 className="text-lg font-semibold">Podgląd na żywo</h2>
          <Badge variant={error ? "destructive" : previewReady ? "success" : "default"}>
            {error ? "Błąd" : isGenerating ? "Generowanie" : previewReady ? "Gotowe" : "Ładowanie"}
          </Badge>
          <Badge variant="outline" className="ml-2">
            {getComponentName()}
          </Badge>
        </div>

        <div className="flex items-center gap-2">
          <Button variant="outline" size="sm" onClick={handleRefreshPreview} disabled={isGenerating || isRefreshing}>
            {isRefreshing ? <Loader2 className="h-4 w-4 mr-1 animate-spin" /> : <RefreshCw className="h-4 w-4 mr-1" />}
            Odśwież
          </Button>

          <Button variant="outline" size="sm" onClick={handleCopyCode}>
            <Copy className="h-4 w-4 mr-1" />
            Kopiuj
          </Button>

          <Button variant="outline" size="sm">
            <Download className="h-4 w-4 mr-1" />
            Pobierz
          </Button>
        </div>
      </div>

      {/* Main content */}
      <div className="flex-1 overflow-hidden">
        <Tabs value={activeTab} onValueChange={setActiveTab} className="flex flex-col h-full">
          <div className="border-b px-2 bg-white">
            <TabsList className="bg-transparent h-12">
              <TabsTrigger value="preview" className="flex items-center">
                <Eye className="mr-2 h-4 w-4" />
                Podgląd
              </TabsTrigger>
              <TabsTrigger value="editor" className="flex items-center">
                <Code className="mr-2 h-4 w-4" />
                Kod
              </TabsTrigger>
              <TabsTrigger value="terminal" className="flex items-center">
                <Terminal className="mr-2 h-4 w-4" />
                Terminal
              </TabsTrigger>
            </TabsList>
          </div>

          <TabsContent value="preview" className="flex-grow p-0 m-0 h-full">
            {error ? (
              <div className="h-full flex flex-col items-center justify-center bg-red-50">
                <AlertCircle className="h-8 w-8 text-red-500 mb-4" />
                <p className="text-red-600 font-medium">{error}</p>
                <p className="text-gray-600 mt-2">Spróbuj ponownie lub zmień parametry promptu</p>
              </div>
            ) : isGenerating ? (
              <div className="h-full flex flex-col items-center justify-center bg-gray-50">
                <Loader2 className="h-8 w-8 text-blue-500 animate-spin mb-4" />
                <p className="text-gray-600">Generuję Twoją aplikację...</p>
              </div>
            ) : (
              <div className="h-full bg-white relative">
                {!previewReady && (
                  <div className="absolute inset-0 flex items-center justify-center bg-gray-50 bg-opacity-75 z-10">
                    <Loader2 className="h-8 w-8 text-blue-500 animate-spin" />
                  </div>
                )}

                {previewError && (
                  <div className="absolute top-0 left-0 right-0 bg-red-50 p-3 border-b border-red-200 z-20">
                    <div className="flex items-start">
                      <AlertCircle className="h-5 w-5 text-red-500 mr-2 flex-shrink-0 mt-0.5" />
                      <div>
                        <p className="text-red-700 font-medium text-sm">Błąd renderowania</p>
                        <pre className="text-xs mt-1 bg-white p-2 rounded border border-red-100 overflow-auto max-h-32">
                          {previewError}
                        </pre>
                      </div>
                    </div>
                  </div>
                )}

                <iframe
                  ref={iframeRef}
                  className="w-full h-full border-0"
                  title="Live Preview"
                  sandbox="allow-scripts allow-same-origin"
                />
              </div>
            )}
          </TabsContent>

          <TabsContent value="editor" className="flex-grow p-0 m-0 h-full">
            <div className="h-full overflow-auto bg-gray-900 text-gray-100 font-mono text-sm p-4">
              <pre className="whitespace-pre-wrap">{code}</pre>
            </div>
          </TabsContent>

          <TabsContent value="terminal" className="flex-grow p-0 m-0 h-full">
            <div className="h-full overflow-auto bg-black text-green-400 font-mono text-sm p-4">
              {error ? (
                <pre className="text-red-400">
                  {`> app@0.1.0 dev
> next dev

Error: ${error}
`}
                </pre>
              ) : previewError ? (
                <pre className="text-yellow-400">
                  {`> app@0.1.0 dev
> next dev

warn  - Preview rendering error: ${previewError}
info  - Application continues to run despite rendering issues
`}
                </pre>
              ) : previewReady ? (
                <pre>
                  {`> app@0.1.0 dev
> next dev

ready - started server on 0.0.0.0:3000, url: http://localhost:3000
info  - Loaded env from .env
event - compiled client and server successfully in 188 ms (175 modules)
wait  - compiling...
event - compiled successfully in 35 ms (175 modules)
info  - Component "${getComponentName()}" rendered successfully`}
                </pre>
              ) : (
                <pre>Terminal gotowy. Oczekiwanie na uruchomienie aplikacji...</pre>
              )}
            </div>
          </TabsContent>
        </Tabs>
      </div>
    </div>
  )
}
