"use client"

// API client for AI services

import { TECHNICAL_PROMPT_TEMPLATE, COMPONENT_TYPES } from "./system-prompts"

// API configuration
const API_CONFIG = {
  baseUrl: "https://api.example.com/v1", // This would be a real API endpoint in production
  timeout: 30000, // 30 seconds
  retries: 2,
}

// Error types
export enum ApiErrorType {
  NETWORK = "network_error",
  TIMEOUT = "timeout_error",
  SERVER = "server_error",
  RATE_LIMIT = "rate_limit_error",
  UNKNOWN = "unknown_error",
}

// API error class
export class ApiError extends Error {
  type: ApiErrorType
  statusCode?: number

  constructor(message: string, type: ApiErrorType, statusCode?: number) {
    super(message)
    this.type = type
    this.statusCode = statusCode
    this.name = "ApiError"
  }
}

// Interface for API responses
interface ApiResponse<T> {
  data: T
  status: string
  metadata?: Record<string, any>
}

// Mock API client for development
export class ApiClient {
  private static instance: ApiClient
  private apiKey: string | null = null

  private constructor() {
    // Private constructor for singleton pattern
  }

  public static getInstance(): ApiClient {
    if (!ApiClient.instance) {
      ApiClient.instance = new ApiClient()
    }
    return ApiClient.instance
  }

  public setApiKey(key: string): void {
    this.apiKey = key
  }

  // Generate assistant response
  public async generateAssistantResponse(userMessage: string): Promise<string> {
    console.log("API Client: Generating assistant response for:", userMessage)

    // In a real implementation, this would make an API call
    // For now, we'll simulate the API call with a delay
    return new Promise((resolve, reject) => {
      // Simulate network delay
      setTimeout(() => {
        try {
          // Check if we should generate a technical prompt
          if (
            userMessage.toLowerCase().includes("stwórz") ||
            userMessage.toLowerCase().includes("zbuduj") ||
            userMessage.toLowerCase().includes("generuj") ||
            userMessage.toLowerCase().includes("zrób") ||
            userMessage.toLowerCase().includes("create") ||
            userMessage.toLowerCase().includes("build") ||
            userMessage.toLowerCase().includes("generate") ||
            userMessage.toLowerCase().includes("make")
          ) {
            resolve(
              `Rozumiem, że chcesz ${userMessage.toLowerCase().includes("stwórz") ? "stworzyć" : "zbudować"} aplikację webową. Mogę Ci w tym pomóc. Jaką konkretną funkcjonalność chciałbyś zaimplementować? Mogę pomóc z komponentami takimi jak formularze, nawigacja, wizualizacja danych lub kompletne strony.`,
            )
          } else if (userMessage.toLowerCase().includes("formularz")) {
            resolve(
              `Mogę przygotować dla Ciebie formularz. Czy chodzi o formularz logowania, rejestracji, czy może kontaktowy? Przygotuję techniczny prompt, który wygeneruje odpowiedni kod.`,
            )
          } else if (userMessage.toLowerCase().includes("dashboard") || userMessage.toLowerCase().includes("panel")) {
            resolve(
              `Panel administracyjny to świetny wybór. Mogę przygotować dla Ciebie dashboard z wykresami, statystykami i listą ostatnich aktywności. Zaraz przygotuję techniczny prompt do zatwierdzenia.`,
            )
          } else {
            resolve(
              `Dziękuję za Twoją wiadomość. Mogę pomóc Ci w tworzeniu aplikacji webowych. Powiedz mi, co konkretnie chciałbyś stworzyć, a przygotuję dla Ciebie odpowiedni kod.`,
            )
          }
        } catch (error) {
          reject(new ApiError("Failed to generate assistant response", ApiErrorType.UNKNOWN))
        }
      }, 1000)
    })
  }

  // Generate technical prompt
  public async generateTechnicalPrompt(userMessage: string): Promise<string> {
    console.log("API Client: Generating technical prompt for:", userMessage)

    return new Promise((resolve, reject) => {
      setTimeout(() => {
        try {
          // Determine component type based on user message
          let componentType = { ...TECHNICAL_PROMPT_TEMPLATE }

          if (userMessage.toLowerCase().includes("logowanie")) {
            componentType = { ...COMPONENT_TYPES.loginForm }
          } else if (userMessage.toLowerCase().includes("rejestracja")) {
            componentType = { ...COMPONENT_TYPES.registerForm }
          } else if (userMessage.toLowerCase().includes("dashboard") || userMessage.toLowerCase().includes("panel")) {
            componentType = { ...COMPONENT_TYPES.dashboard }
          } else if (userMessage.toLowerCase().includes("formularz")) {
            componentType = {
              task: "Stwórz formularz",
              component: "CustomForm",
              language: "React",
              requirements: ["responsywny interfejs", "obsługa walidacji formularzy", "interaktywne elementy UI"],
            }
          } else {
            componentType.task = userMessage.toLowerCase().includes("strona") ? "Stwórz stronę" : "Stwórz komponent"
            componentType.component = "CustomComponent"
            componentType.additionalContext = userMessage
          }

          resolve(JSON.stringify(componentType, null, 2))
        } catch (error) {
          reject(new ApiError("Failed to generate technical prompt", ApiErrorType.UNKNOWN))
        }
      }, 800)
    })
  }

  // Generate code from prompt
  public async generateCode(prompt: string): Promise<{ output: string; status: string }> {
    console.log("API Client: Generating code from prompt:", prompt)

    return new Promise((resolve, reject) => {
      setTimeout(() => {
        try {
          // Parse the JSON prompt
          const promptData = JSON.parse(prompt)

          // Generate code based on the component type
          let generatedCode = ""

          if (promptData.component === "LoginForm") {
            generatedCode = `
// Wygenerowany kod formularza logowania
import { useState } from 'react'
import { useRouter } from 'next/navigation'

export default function LoginForm() {
  const router = useRouter()
  const [formData, setFormData] = useState({
    email: '',
    password: ''
  })
  const [errors, setErrors] = useState({})
  const [isLoading, setIsLoading] = useState(false)
  
  const handleChange = (e) => {
    const { name, value } = e.target
    setFormData(prev => ({
      ...prev,
      [name]: value
    }))
    
    // Wyczyść błąd dla tego pola
    if (errors[name]) {
      setErrors(prev => ({
        ...prev,
        [name]: null
      }))
    }
  }
  
  const validateForm = () => {
    const newErrors = {}
    
    if (!formData.email) {
      newErrors.email = 'Email jest wymagany'
    } else if (!/\\S+@\\S+\\.\\S+/.test(formData.email)) {
      newErrors.email = 'Nieprawidłowy format email'
    }
    
    if (!formData.password) {
      newErrors.password = 'Hasło jest wymagane'
    }
    
    setErrors(newErrors)
    return Object.keys(newErrors).length === 0
  }
  
  const handleSubmit = async (e) => {
    e.preventDefault()
    
    if (!validateForm()) return
    
    setIsLoading(true)
    
    try {
      // Symulacja wysłania danych do API
      await new Promise(resolve => setTimeout(resolve, 1000))
      
      // W rzeczywistej aplikacji, tutaj byłoby wywołanie API
      // const response = await fetch('/api/login', {
      //   method: 'POST',
      //   headers: { 'Content-Type': 'application/json' },
      //   body: JSON.stringify(formData)
      // })
      
      // if (!response.ok) throw new Error('Błąd logowania')
      
      // Przekierowanie po udanym logowaniu
      router.push('/dashboard')
    } catch (error) {
      setErrors({ form: 'Nieprawidłowy email lub hasło' })
    } finally {
      setIsLoading(false)
    }
  }
  
  return (
    <div className="flex min-h-screen flex-col items-center justify-center p-4 bg-gray-50">
      <div className="w-full max-w-md p-8 space-y-8 bg-white rounded-lg shadow-md">
        <div className="text-center">
          <h1 className="text-3xl font-bold text-gray-900">Zaloguj się</h1>
          <p className="mt-2 text-gray-600">Wprowadź swoje dane, aby się zalogować</p>
        </div>
        
        {errors.form && (
          <div className="p-3 text-sm text-red-600 bg-red-100 rounded-md">
            {errors.form}
          </div>
        )}
        
        <form onSubmit={handleSubmit} className="mt-8 space-y-6">
          <div>
            <label htmlFor="email" className="block text-sm font-medium text-gray-700">
              Email
            </label>
            <input
              id="email"
              name="email"
              type="email"
              autoComplete="email"
              value={formData.email}
              onChange={handleChange}
              className={\`mt-1 block w-full px-3 py-2 border \${
                errors.email ? 'border-red-300' : 'border-gray-300'
              } rounded-md shadow-sm focus:outline-none focus:ring-blue-500 focus:border-blue-500\`}
            />
            {errors.email && (
              <p className="mt-1 text-sm text-red-600">{errors.email}</p>
            )}
          </div>
          
          <div>
            <label htmlFor="password" className="block text-sm font-medium text-gray-700">
              Hasło
            </label>
            <input
              id="password"
              name="password"
              type="password"
              autoComplete="current-password"
              value={formData.password}
              onChange={handleChange}
              className={\`mt-1 block w-full px-3 py-2 border \${
                errors.password ? 'border-red-300' : 'border-gray-300'
              } rounded-md shadow-sm focus:outline-none focus:ring-blue-500 focus:border-blue-500\`}
            />
            {errors.password && (
              <p className="mt-1 text-sm text-red-600">{errors.password}</p>
            )}
          </div>
          
          <div className="flex items-center justify-between">
            <div className="flex items-center">
              <input
                id="remember-me"
                name="remember-me"
                type="checkbox"
                className="h-4 w-4 text-blue-600 focus:ring-blue-500 border-gray-300 rounded"
              />
              <label htmlFor="remember-me" className="ml-2 block text-sm text-gray-700">
                Zapamiętaj mnie
              </label>
            </div>
            
            <div className="text-sm">
              <a href="#" className="font-medium text-blue-600 hover:text-blue-500">
                Zapomniałeś hasła?
              </a>
            </div>
          </div>
          
          <div>
            <button
              type="submit"
              disabled={isLoading}
              className="w-full flex justify-center py-2 px-4 border border-transparent rounded-md shadow-sm text-sm font-medium text-white bg-blue-600 hover:bg-blue-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-blue-500 disabled:opacity-50 disabled:cursor-not-allowed"
            >
              {isLoading ? 'Logowanie...' : 'Zaloguj się'}
            </button>
          </div>
        </form>
        
        <div className="mt-6 text-center">
          <p className="text-sm text-gray-600">
            Nie masz konta?{' '}
            <a href="#" className="font-medium text-blue-600 hover:text-blue-500">
              Zarejestruj się
            </a>
          </p>
        </div>
      </div>
    </div>
  )
}`
          } else if (promptData.component === "RegisterForm") {
            generatedCode = `
// Wygenerowany kod formularza rejestracji
import { useState } from 'react'
import { useRouter } from 'next/navigation'

export default function RegisterForm() {
  const router = useRouter()
  const [formData, setFormData] = useState({
    name: '',
    email: '',
    password: '',
    confirmPassword: ''
  })
  const [errors, setErrors] = useState({})
  const [isLoading, setIsLoading] = useState(false)
  
  const handleChange = (e) => {
    const { name, value } = e.target
    setFormData(prev => ({
      ...prev,
      [name]: value
    }))
    
    // Wyczyść błąd dla tego pola
    if (errors[name]) {
      setErrors(prev => ({
        ...prev,
        [name]: null
      }))
    }
  }
  
  const validateForm = () => {
    const newErrors = {}
    
    if (!formData.name) {
      newErrors.name = 'Imię jest wymagane'
    }
    
    if (!formData.email) {
      newErrors.email = 'Email jest wymagany'
    } else if (!/\\S+@\\S+\\.\\S+/.test(formData.email)) {
      newErrors.email = 'Nieprawidłowy format email'
    }
    
    if (!formData.password) {
      newErrors.password = 'Hasło jest wymagane'
    } else if (formData.password.length < 6) {
      newErrors.password = 'Hasło musi mieć co najmniej 6 znaków'
    }
    
    if (!formData.confirmPassword) {
      newErrors.confirmPassword = 'Potwierdzenie hasła jest wymagane'
    } else if (formData.password !== formData.confirmPassword) {
      newErrors.confirmPassword = 'Hasła nie są zgodne'
    }
    
    setErrors(newErrors)
    return Object.keys(newErrors).length === 0
  }
  
  const handleSubmit = async (e) => {
    e.preventDefault()
    
    if (!validateForm()) return
    
    setIsLoading(true)
    
    try {
      // Symulacja wysłania danych do API
      await new Promise(resolve => setTimeout(resolve, 1000))
      
      // W rzeczywistej aplikacji, tutaj byłoby wywołanie API
      // const response = await fetch('/api/register', {
      //   method: 'POST',
      //   headers: { 'Content-Type': 'application/json' },
      //   body: JSON.stringify(formData)
      // })
      
      // if (!response.ok) throw new Error('Błąd rejestracji')
      
      // Przekierowanie po udanej rejestracji
      router.push('/login')
    } catch (error) {
      setErrors({ form: 'Wystąpił błąd podczas rejestracji. Spróbuj ponownie.' })
    } finally {
      setIsLoading(false)
    }
  }
  
  return (
    <div className="flex min-h-screen flex-col items-center justify-center p-4 bg-gray-50">
      <div className="w-full max-w-md p-8 space-y-8 bg-white rounded-lg shadow-md">
        <div className="text-center">
          <h1 className="text-3xl font-bold text-gray-900">Zarejestruj się</h1>
          <p className="mt-2 text-gray-600">Utwórz nowe konto, aby korzystać z aplikacji</p>
        </div>
        
        {errors.form && (
          <div className="p-3 text-sm text-red-600 bg-red-100 rounded-md">
            {errors.form}
          </div>
        )}
        
        <form onSubmit={handleSubmit} className="mt-8 space-y-6">
          <div>
            <label htmlFor="name" className="block text-sm font-medium text-gray-700">
              Imię
            </label>
            <input
              id="name"
              name="name"
              type="text"
              autoComplete="name"
              value={formData.name}
              onChange={handleChange}
              className={\`mt-1 block w-full px-3 py-2 border \${
                errors.name ? 'border-red-300' : 'border-gray-300'
              } rounded-md shadow-sm focus:outline-none focus:ring-blue-500 focus:border-blue-500\`}
            />
            {errors.name && (
              <p className="mt-1 text-sm text-red-600">{errors.name}</p>
            )}
          </div>
          
          <div>
            <label htmlFor="email" className="block text-sm font-medium text-gray-700">
              Email
            </label>
            <input
              id="email"
              name="email"
              type="email"
              autoComplete="email"
              value={formData.email}
              onChange={handleChange}
              className={\`mt-1 block w-full px-3 py-2 border \${
                errors.email ? 'border-red-300' : 'border-gray-300'
              } rounded-md shadow-sm focus:outline-none focus:ring-blue-500 focus:border-blue-500\`}
            />
            {errors.email && (
              <p className="mt-1 text-sm text-red-600">{errors.email}</p>
            )}
          </div>
          
          <div>
            <label htmlFor="password" className="block text-sm font-medium text-gray-700">
              Hasło
            </label>
            <input
              id="password"
              name="password"
              type="password"
              autoComplete="new-password"
              value={formData.password}
              onChange={handleChange}
              className={\`mt-1 block w-full px-3 py-2 border \${
                errors.password ? 'border-red-300' : 'border-gray-300'
              } rounded-md shadow-sm focus:outline-none focus:ring-blue-500 focus:border-blue-500\`}
            />
            {errors.password && (
              <p className="mt-1 text-sm text-red-600">{errors.password}</p>
            )}
          </div>
          
          <div>
            <label htmlFor="confirmPassword" className="block text-sm font-medium text-gray-700">
              Potwierdź hasło
            </label>
            <input
              id="confirmPassword"
              name="confirmPassword"
              type="password"
              autoComplete="new-password"
              value={formData.confirmPassword}
              onChange={handleChange}
              className={\`mt-1 block w-full px-3 py-2 border \${
                errors.confirmPassword ? 'border-red-300' : 'border-gray-300'
              } rounded-md shadow-sm focus:outline-none focus:ring-blue-500 focus:border-blue-500\`}
            />
            {errors.confirmPassword && (
              <p className="mt-1 text-sm text-red-600">{errors.confirmPassword}</p>
            )}
          </div>
          
          <div>
            <button
              type="submit"
              disabled={isLoading}
              className="w-full flex justify-center py-2 px-4 border border-transparent rounded-md shadow-sm text-sm font-medium text-white bg-blue-600 hover:bg-blue-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-blue-500 disabled:opacity-50 disabled:cursor-not-allowed"
            >
              {isLoading ? 'Rejestracja...' : 'Zarejestruj się'}
            </button>
          </div>
        </form>
        
        <div className="mt-6 text-center">
          <p className="text-sm text-gray-600">
            Masz już konto?{' '}
            <a href="#" className="font-medium text-blue-600 hover:text-blue-500">
              Zaloguj się
            </a>
          </p>
        </div>
      </div>
    </div>
  )
}`
          } else if (promptData.component === "Dashboard") {
            generatedCode = `
// Wygenerowany kod dashboardu
import { useState } from 'react'

export default function Dashboard() {
  const [activeTab, setActiveTab] = useState('overview')
  
  // Przykładowe dane dla wykresu
  const chartData = [
    { name: 'Sty', value: 400 },
    { name: 'Lut', value: 300 },
    { name: 'Mar', value: 600 },
    { name: 'Kwi', value: 800 },
    { name: 'Maj', value: 500 },
    { name: 'Cze', value: 900 },
    { name: 'Lip', value: 750 },
  ]
  
  // Przykładowe dane dla ostatnich aktywności
  const activities = [
    { id: 1, action: 'Nowy użytkownik zarejestrowany', time: '2 minuty temu' },
    { id: 2, action: 'Zaktualizowano ustawienia', time: '1 godzinę temu' },
    { id: 3, action: 'Nowy komentarz dodany', time: '3 godziny temu' },
    { id: 4, action: 'Zadanie ukończone', time: '5 godzin temu' },
    { id: 5, action: 'Plik przesłany', time: '1 dzień temu' },
  ]
  
  // Przykładowe dane dla statystyk
  const stats = [
    { id: 1, name: 'Użytkownicy', value: '1,234', change: '+12%', trend: 'up' },
    { id: 2, name: 'Sesje', value: '5,678', change: '+8%', trend: 'up' },
    { id: 3, name: 'Czas na stronie', value: '2m 45s', change: '-3%', trend: 'down' },
    { id: 4, name: 'Współczynnik odrzuceń', value: '42%', change: '-5%', trend: 'up' },
  ]
  
  // Funkcja renderująca wykres słupkowy
  const renderBarChart = () => {
    const maxValue = Math.max(...chartData.map(item => item.value))
    
    return (
      <div className="h-64 flex items-end space-x-2">
        {chartData.map((item, index) => (
          <div key={index} className="flex flex-col items-center flex-1">
            <div 
              className="w-full bg-blue-500 rounded-t"
              style={{ height: \`\${(item.value / maxValue) * 100}%\` }}
            ></div>
            <div className="text-xs mt-1">{item.name}</div>
          </div>
        ))}
      </div>
    )
  }
  
  return (
    <div className="min-h-screen bg-gray-100">
      <nav className="bg-white shadow-sm">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="flex justify-between h-16">
            <div className="flex">
              <div className="flex-shrink-0 flex items-center">
                <h1 className="text-xl font-bold text-gray-900">Panel administracyjny</h1>
              </div>
            </div>
            <div className="flex items-center">
              <button className="p-1 rounded-full text-gray-400 hover:text-gray-500 focus:outline-none">
                <span className="sr-only">Zobacz powiadomienia</span>
                <svg className="h-6 w-6" xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                  <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M15 17h5l-1.405-1.405A2.032 2.032 0 0118 14.158V11a6.002 6.002 0 00-4-5.659V5a2 2 0 10-4 0v.341C7.67 6.165 6 8.388 6 11v3.159c0 .538-.214 1.055-.595 1.436L4 17h5m6 0v1a3 3 0 11-6 0v-1m6 0H9" />
                </svg>
              </button>
              <div className="ml-3 relative">
                <div>
                  <button className="flex text-sm border-2 border-transparent rounded-full focus:outline-none focus:border-gray-300 transition duration-150 ease-in-out">
                    <img className="h-8 w-8 rounded-full" src="https://images.unsplash.com/photo-1472099645785-5658abf4ff4e?ixlib=rb-1.2.1&ixid=eyJhcHBfaWQiOjEyMDd9&auto=format&fit=facearea&facepad=2&w=256&h=256&q=80" alt="" />  alt="" />
                  </button>
                </div>
              </div>
            </div>
          </div>
        </div>
      </nav>

      <div className="py-6">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <h1 className="text-2xl font-semibold text-gray-900">Dashboard</h1>
        </div>
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          {/* Tabs */}
          <div className="mt-4 border-b border-gray-200">
            <nav className="-mb-px flex space-x-8">
              <button
                onClick={() => setActiveTab('overview')}
                className={\`\${
                  activeTab === 'overview'
                    ? 'border-blue-500 text-blue-600'
                    : 'border-transparent text-gray-500 hover:text-gray-700 hover:border-gray-300'
                } whitespace-nowrap py-4 px-1 border-b-2 font-medium text-sm\`}
              >
                Przegląd
              </button>
              <button
                onClick={() => setActiveTab('analytics')}
                className={\`\${
                  activeTab === 'analytics'
                    ? 'border-blue-500 text-blue-600'
                    : 'border-transparent text-gray-500 hover:text-gray-700 hover:border-gray-300'
                } whitespace-nowrap py-4 px-1 border-b-2 font-medium text-sm\`}
              >
                Analityka
              </button>
              <button
                onClick={() => setActiveTab('reports')}
                className={\`\${
                  activeTab === 'reports'
                    ? 'border-blue-500 text-blue-600'
                    : 'border-transparent text-gray-500 hover:text-gray-700 hover:border-gray-300'
                } whitespace-nowrap py-4 px-1 border-b-2 font-medium text-sm\`}
              >
                Raporty
              </button>
              <button
                onClick={() => setActiveTab('settings')}
                className={\`\${
                  activeTab === 'settings'
                    ? 'border-blue-500 text-blue-600'
                    : 'border-transparent text-gray-500 hover:text-gray-700 hover:border-gray-300'
                } whitespace-nowrap py-4 px-1 border-b-2 font-medium text-sm\`}
              >
                Ustawienia
              </button>
            </nav>
          </div>

          {/* Stats */}
          <div className="mt-6 grid grid-cols-1 gap-5 sm:grid-cols-2 lg:grid-cols-4">
            {stats.map((stat) => (
              <div key={stat.id} className="bg-white overflow-hidden shadow rounded-lg">
                <div className="px-4 py-5 sm:p-6">
                  <div className="flex items-center">
                    <div className="flex-shrink-0 bg-blue-500 rounded-md p-3">
                      <svg className="h-6 w-6 text-white" xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                        <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M12 6v6m0 0v6m0-6h6m-6 0H6" />
                      </svg>
                    </div>
                    <div className="ml-5 w-0 flex-1">
                      <dl>
                        <dt className="text-sm font-medium text-gray-500 truncate">{stat.name}</dt>
                        <dd>
                          <div className="flex items-baseline">
                            <div className="text-2xl font-semibold text-gray-900">{stat.value}</div>
                            <div className={\`ml-2 flex items-baseline text-sm font-semibold \${
                              stat.trend === 'up' ? 'text-green-600' : 'text-red-600'
                            }\`}>
                              {stat.change}
                            </div>
                          </div>
                        </dd>
                      </dl>
                    </div>
                  </div>
                </div>
              </div>
            ))}
          </div>

          {/* Chart */}
          <div className="mt-8">
            <div className="bg-white shadow rounded-lg p-6">
              <h3 className="text-lg leading-6 font-medium text-gray-900 mb-4">Aktywność użytkowników</h3>
              <div className="h-80">
                {renderBarChart()}
              </div>
            </div>
          </div>

          {/* Recent Activity */}
          <div className="mt-8">
            <div className="bg-white shadow rounded-lg">
              <div className="px-4 py-5 border-b border-gray-200 sm:px-6">
                <h3 className="text-lg leading-6 font-medium text-gray-900">Ostatnie aktywności</h3>
              </div>
              <ul className="divide-y divide-gray-200">
                {activities.map((activity) => (
                  <li key={activity.id} className="px-4 py-4 sm:px-6">
                    <div className="flex items-center justify-between">
                      <p className="text-sm font-medium text-gray-900 truncate">{activity.action}</p>
                      <div className="ml-2 flex-shrink-0 flex">
                        <p className="px-2 inline-flex text-xs leading-5 font-semibold rounded-full bg-green-100 text-green-800">
                          {activity.time}
                        </p>
                      </div>
                    </div>
                  </li>
                ))}
              </ul>
              <div className="px-4 py-4 sm:px-6">
                <a href="#" className="text-sm font-medium text-blue-600 hover:text-blue-500">
                  Zobacz wszystkie aktywności <span aria-hidden="true">&rarr;</span>
                </a>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  )
}`
          } else {
            // Default component
            generatedCode = `
// Wygenerowany komponent na podstawie promptu: ${promptData.task}
import { useState } from 'react'

export default function ${promptData.component}() {
  const [isActive, setIsActive] = useState(false)
  
  return (
    <div className="flex min-h-screen flex-col items-center justify-center p-24 bg-gradient-to-b from-blue-50 to-white">
      <h1 className="text-4xl font-bold mb-8 text-blue-800">Aplikacja wygenerowana przez AI</h1>
      <p className="mb-6 text-gray-600 max-w-md text-center">
        Ta aplikacja została wygenerowana na podstawie Twoich wymagań przy użyciu sztucznej inteligencji.
        Możesz ją dowolnie modyfikować i rozszerzać według potrzeb.
      </p>
      
      <div className="p-6 border rounded-xl shadow-lg bg-white w-full max-w-md">
        <h2 className="text-2xl font-semibold mb-4 text-gray-800">Interaktywny komponent</h2>
        <p className="mb-4 text-gray-600">
          Kliknij przycisk poniżej, aby zmienić stan:
        </p>
        
        <div className={\`p-4 rounded-md transition-all duration-300 \${
          isActive ? 'bg-blue-100 border border-blue-300' : 'bg-gray-100 border border-gray-200'
        }\`}>
          <p className="text-lg mb-3">
            Status: <span className="font-medium">{isActive ? 'Aktywny' : 'Nieaktywny'}</span>
          </p>
          <button 
            onClick={() => setIsActive(!isActive)}
            className="px-4 py-2 bg-blue-600 text-white rounded-md hover:bg-blue-700 transition-colors"
          >
            {isActive ? 'Dezaktywuj' : 'Aktywuj'}
          </button>
        </div>
      </div>
    </div>
  )
}`
          }

          // Create a response object similar to what would be returned by the API
          const response = {
            status: "success",
            output: generatedCode,
            errors: null,
            metadata: {
              usedLibraries: ["react", "next", "tailwindcss"],
            },
          }

          resolve(response)
        } catch (error) {
          // Handle any errors
          reject(new ApiError("Failed to generate code", ApiErrorType.UNKNOWN))
        }
      }, 3000) // Simulate a 3-second delay
    })
  }
}
