"use client"

// Gemini API client for AI services
import { ASSISTANT_SYSTEM_PROMPT, PROGRAMMER_SYSTEM_PROMPT } from "./system-prompts"

// API configuration
const API_CONFIG = {
  baseUrl: "https://generativelanguage.googleapis.com/v1beta",
  model: "models/gemini-1.5-pro-latest",
  timeout: 60000, // 60 seconds
  maxRetries: 2,
}

// Error types
export enum ApiErrorType {
  NETWORK = "network_error",
  TIMEOUT = "timeout_error",
  SERVER = "server_error",
  RATE_LIMIT = "rate_limit_error",
  AUTHENTICATION = "authentication_error",
  UNKNOWN = "unknown_error",
}

// API error class
export class ApiError extends Error {
  type: ApiErrorType
  statusCode?: number

  constructor(message: string, type: ApiErrorType, statusCode?: number) {
    super(message)
    this.type = type
    this.statusCode = statusCode
    this.name = "ApiError"
  }
}

// Gemini API client
export class GeminiClient {
  private static instance: GeminiClient
  private apiKey: string | null = null

  private constructor() {
    // Private constructor for singleton pattern
  }

  public static getInstance(): GeminiClient {
    if (!GeminiClient.instance) {
      GeminiClient.instance = new GeminiClient()
    }
    return GeminiClient.instance
  }

  public setApiKey(key: string): void {
    this.apiKey = key
  }

  private async makeRequest(endpoint: string, body: any): Promise<any> {
    if (!this.apiKey) {
      throw new ApiError("API key not set", ApiErrorType.AUTHENTICATION)
    }

    const url = `${API_CONFIG.baseUrl}/${endpoint}?key=${this.apiKey}`

    try {
      const response = await fetch(url, {
        method: "POST",
        headers: {
          "Content-Type": "application/json",
        },
        body: JSON.stringify(body),
      })

      if (!response.ok) {
        const errorData = await response.json().catch(() => ({}))
        const errorMessage = errorData.error?.message || `API request failed with status ${response.status}`

        let errorType = ApiErrorType.SERVER
        if (response.status === 401 || response.status === 403) {
          errorType = ApiErrorType.AUTHENTICATION
        } else if (response.status === 429) {
          errorType = ApiErrorType.RATE_LIMIT
        }

        throw new ApiError(errorMessage, errorType, response.status)
      }

      return await response.json()
    } catch (error) {
      if (error instanceof ApiError) {
        throw error
      }

      if (error instanceof TypeError && error.message.includes("fetch")) {
        throw new ApiError("Network error", ApiErrorType.NETWORK)
      }

      throw new ApiError(error instanceof Error ? error.message : "Unknown error occurred", ApiErrorType.UNKNOWN)
    }
  }

  // Generate text with Gemini API
  public async generateText(
    prompt: string,
    systemPrompt: string,
    temperature = 0.7,
    maxOutputTokens = 2048,
  ): Promise<string> {
    try {
      const body = {
        contents: [
          {
            role: "user",
            parts: [
              {
                text: systemPrompt + "\n\n" + prompt,
              },
            ],
          },
        ],
        generationConfig: {
          temperature,
          maxOutputTokens,
          topP: 0.95,
          topK: 64,
        },
        safetySettings: [
          {
            category: "HARM_CATEGORY_HARASSMENT",
            threshold: "BLOCK_MEDIUM_AND_ABOVE",
          },
          {
            category: "HARM_CATEGORY_HATE_SPEECH",
            threshold: "BLOCK_MEDIUM_AND_ABOVE",
          },
          {
            category: "HARM_CATEGORY_SEXUALLY_EXPLICIT",
            threshold: "BLOCK_MEDIUM_AND_ABOVE",
          },
          {
            category: "HARM_CATEGORY_DANGEROUS_CONTENT",
            threshold: "BLOCK_MEDIUM_AND_ABOVE",
          },
        ],
      }

      const response = await this.makeRequest(`${API_CONFIG.model}:generateContent`, body)

      if (!response.candidates || response.candidates.length === 0) {
        throw new ApiError("No response generated", ApiErrorType.UNKNOWN)
      }

      if (response.candidates[0].finishReason === "SAFETY") {
        throw new ApiError("Response was blocked for safety reasons", ApiErrorType.UNKNOWN)
      }

      return response.candidates[0].content.parts[0].text
    } catch (error) {
      console.error("Error generating text with Gemini:", error)
      throw error
    }
  }

  // Generate assistant response
  public async generateAssistantResponse(userMessage: string): Promise<string> {
    return this.generateText(userMessage, ASSISTANT_SYSTEM_PROMPT, 0.7, 2048)
  }

  // Generate technical prompt
  public async generateTechnicalPrompt(userMessage: string): Promise<string> {
    const prompt = `
Generate a technical prompt in JSON format for creating a React component based on this user request:
"${userMessage}"

The JSON should include:
- task: A brief description of what to create
- component: A name for the component (PascalCase)
- language: "React"
- requirements: An array of specific requirements for the component
- styling: "Tailwind CSS"

Make sure the JSON is valid and properly formatted.
`
    return this.generateText(prompt, ASSISTANT_SYSTEM_PROMPT, 0.3, 1024)
  }

  // Generate code from prompt
  public async generateCode(prompt: string): Promise<{ output: string; status: string }> {
    try {
      const code = await this.generateText(prompt, PROGRAMMER_SYSTEM_PROMPT, 0.2, 8192)

      return {
        output: code,
        status: "success",
      }
    } catch (error) {
      console.error("Error generating code:", error)
      throw error
    }
  }
}
